﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Data.Services.Client;
using NetflixCatalog.Model;


namespace SFDemo
{

    public class MainViewModel : INotifyPropertyChanged
    {

        #region Constructor

        public MainViewModel()
        {
            LoadData();
        }

        #endregion


        #region Properties

        private DataServiceCollection<Title> _titles;
        public DataServiceCollection<Title> Titles
        {
            get
            {
                return _titles;
            }
            set
            {
                if (_titles == value)
                {
                    return;
                }
                _titles = value;
                NotifyPropertyChanged("Titles");
            }
        }

        public bool IsDataLoaded
        {
            get;
            private set;
        }

        #endregion

        #region Public Methods

        public void LoadData()
        {
            if (!IsDataLoaded)
            {
                Uri serviceUri = new Uri("http://odata.netflix.com/catalog", UriKind.Absolute);
                NetflixCatalog.Model.NetflixCatalog catalog = new NetflixCatalog.Model.NetflixCatalog(serviceUri);
                Uri queryUri = new Uri("/Titles?$filter=ReleaseYear gt 2009&$top=20", UriKind.Relative);

                _titles = new DataServiceCollection<Title>(catalog);
                _titles.LoadAsync(queryUri);

                this.IsDataLoaded = true;
            }
        }

        #endregion

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (null != handler)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

    }
}